@@ -1217,7 +1217,7 @@ class ButtonFunctions:
 			
 class MiscFunctions:
 	def controlLircd(self, cmd): # Starting and stoping lirc
-		arg = ["rootsh","/etc/init.d/lirc", cmd]
+		arg = ["sudo","/etc/init.d/lirc", cmd]
 		lircing = subprocess.Popen(arg)
 		lircing.wait()
 
